@@ -138,8 +138,10 @@ class MariaDBReader(AbstractReader):
         config string as user:password@host:port/database
         or dictionary like
         """
-        try:                
-            if re.match('.*[:].*[@].*',config):
+        try:
+            if not isinstance(config,str):
+                config = dict(config)
+            elif re.match('.*[:].*[@].*',config):
                 h = config.split('@')
                 u,p = h[0].split(':')
                 config = {'user':u,'password':p}
@@ -284,7 +286,7 @@ class MariaDBReader(AbstractReader):
             start_date, stop_date=None,
             decimate=None,
             correlate = False,
-            columns = '',
+            columns = '', cast='DOUBLE',
             **params):
         """
         Returns attributes values between start and stop dates
@@ -305,6 +307,8 @@ class MariaDBReader(AbstractReader):
                        each attribute.
             columns: columns separated by commas
                     time, r_value, w_value, quality, error_desc
+            cast: it may be "DOUBLE" for return time as native python floats
+                    or DECIMAL(17,6) to return full precission with us
 
         returns:
             {'attr0':[(epoch0, r_value, w_value, quality, error_desc),
@@ -340,7 +344,7 @@ class MariaDBReader(AbstractReader):
 
                 if 'data_time,' in cols:
                     cols = cols.replace('data_time,',
-                        'CAST(UNIX_TIMESTAMP(data_time) AS DOUBLE),')
+                        'CAST(UNIX_TIMESTAMP(data_time) AS %s),' % cast)
 
                 tcol = 'int_time' if int_time else 'data_time'
                 q = ('select %s from %s where '
@@ -364,7 +368,7 @@ class MariaDBReader(AbstractReader):
                         
                 q += ' order by %s_time' % ('data','int')[int_time]
                     
-                
+                #print(q)
                 data[a] = self._query(q, prune=decimate)
                 #print('obtained data: {}'.format(len(data[a]),'L'))
             except:
