@@ -9,7 +9,7 @@ import importlib
 import collections.abc
 import traceback
 
-from .utils import load_config_from_tango, logger, parse_config_string
+from .utils import logger, load_config_from_tango, parse_config_string
 
 ###############################################################################
 
@@ -58,10 +58,16 @@ def get_default_reader(tango_host=''):
         else:
             tangodb = tango.Database()
 
-        schema = tangodb.get_property('HDB++','DefaultSchema'
+        try:
+            schema = tangodb.get_property('HDB++','DefaultSchema'
                         )['DefaultSchema'][0]        
-        logger.info('tango://DefaultSchema: %s' % str(schema))
-        data = load_config_from_tango(schema)
+            root = 'HDB++'
+        except:
+            schema = 'HdbConfigurationManager'
+            root = tangodb.get_device_exported_for_class(schema)[0]
+            
+        logger.info('tango://DefaultSchema: %s:%s' % (schema,root))
+        data = load_config_from_tango(schema,root=root)
         return reader(apiclass=data['apiclass'],config=data)
     
     except:
@@ -77,13 +83,8 @@ def reader(apiclass='pyhdbpp.abstract.AbstractReader', config=None):
     Initialize a reader object, based on the specified backend
     and a config dictionnary.
     """
-    logger.info('Creating pyhdbpp.reader(%s,%s)' % (apiclass,config))
-    
-    apiclass = config.get('apiclass',apiclass)
-    mod_name, class_name = apiclass.rsplit('.', 1)
-    module = importlib.import_module(mod_name)        
-    apiclass = getattr(module, class_name)
-    
+    logger.debug('Creating pyhdbpp.reader(%s,%s)' % (apiclass,config))
+       
     if not config:
         return get_default_reader()
 
@@ -96,11 +97,19 @@ def reader(apiclass='pyhdbpp.abstract.AbstractReader', config=None):
         elif config:
             config = parse_config_string(config)
             
-        print(config)
-        
-        if not validate_config(config):
-            logger.error(config)
-            raise Exception('InvalidConfig')
+    config['database'] = config.get('database',config.get('db_name','hdb'))
+    config['password'] = config.get('password',config.get('passwd',''))
+    #print(config)
+    
+    if not validate_config(config):
+        logger.error(config)
+        raise Exception('InvalidConfig')
+
+    # config should be a dict at this point
+    apiclass = config.get('apiclass',apiclass)
+    mod_name, class_name = apiclass.rsplit('.', 1)
+    module = importlib.import_module(mod_name)        
+    apiclass = getattr(module, class_name)
     
     return apiclass(**config)
 
